# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_nvme.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x66rontend_nvme.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\x93\x02\n\rNvmeSubsystem\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32%.opi_api.storage.v1.NvmeSubsystemSpecB\x04\xe2\x41\x01\x02R\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\'.opi_api.storage.v1.NvmeSubsystemStatusB\x04\xe2\x41\x01\x03R\x06status:`\xea\x41]\n opi_api.storage.v1/NvmeSubsystem\x12\x1anvmeSubsystems/{subsystem}*\x0envmeSubsystems2\rnvmeSubsystem\"\xe4\x01\n\x11NvmeSubsystemSpec\x12\x16\n\x03nqn\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03nqn\x12)\n\rserial_number\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0cserialNumber\x12\'\n\x0cmodel_number\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x0bmodelNumber\x12+\n\x0emax_namespaces\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\rmaxNamespaces\x12\x1e\n\x07hostnqn\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01R\x07hostnqn\x12\x16\n\x03psk\x18\x06 \x01(\x0c\x42\x04\xe2\x41\x01\x01R\x03psk\"i\n\x13NvmeSubsystemStatus\x12\x31\n\x11\x66irmware_revision\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x66irmwareRevision\x12\x1f\n\x08\x66ru_guid\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x03R\x07\x66ruGuid\"\xb7\x02\n\x0eNvmeController\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12@\n\x04spec\x18\x02 \x01(\x0b\x32&.opi_api.storage.v1.NvmeControllerSpecB\x04\xe2\x41\x01\x02R\x04spec\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32(.opi_api.storage.v1.NvmeControllerStatusB\x04\xe2\x41\x01\x03R\x06status:\x80\x01\xea\x41}\n!opi_api.storage.v1/NvmeController\x12\x37nvmeSubsystems/{subsystem}/nvmeControllers/{controller}*\x0fnvmeControllers2\x0envmeController\"\xe4\x04\n\x12NvmeControllerSpec\x12\x37\n\x12nvme_controller_id\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x10nvmeControllerId\x88\x01\x01\x12\x43\n\x06trtype\x18\x02 \x01(\x0e\x32%.opi_api.storage.v1.NvmeTransportTypeB\x04\xe2\x41\x01\x02R\x06trtype\x12@\n\x07pcie_id\x18\x03 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpointB\x04\xe2\x41\x01\x01H\x00R\x06pcieId\x12J\n\nfabrics_id\x18\x04 \x01(\x0b\x32#.opi_api.storage.v1.FabricsEndpointB\x04\xe2\x41\x01\x01H\x00R\tfabricsId\x12\x1d\n\x07max_nsq\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x06maxNsq\x12\x1d\n\x07max_ncq\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x06maxNcq\x12\x18\n\x04sqes\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x04sqes\x12\x18\n\x04\x63qes\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x04\x63qes\x12+\n\x0emax_namespaces\x18\t \x01(\x05\x42\x04\xe2\x41\x01\x01R\rmaxNamespaces\x12?\n\tmin_limit\x18\n \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08minLimit\x12?\n\tmax_limit\x18\x0b \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08maxLimitB\n\n\x08\x65ndpointB\x15\n\x13_nvme_controller_id\"4\n\x14NvmeControllerStatus\x12\x1c\n\x06\x61\x63tive\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x61\x63tive\"\xae\x02\n\rNvmeNamespace\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32%.opi_api.storage.v1.NvmeNamespaceSpecB\x04\xe2\x41\x01\x02R\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\'.opi_api.storage.v1.NvmeNamespaceStatusB\x04\xe2\x41\x01\x03R\x06status:{\xea\x41x\n opi_api.storage.v1/NvmeNamespace\x12\x35nvmeSubsystems/{subsystem}/nvmeNamespaces/{namespace}*\x0envmeNamespaces2\rnvmeNamespace\"\xb6\x01\n\x11NvmeNamespaceSpec\x12!\n\thost_nsid\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08hostNsid\x12\x1a\n\x05nguid\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x05nguid\x12\x1a\n\x05\x65ui64\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x05\x65ui64\x12\x18\n\x04uuid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid\x12,\n\x0fvolume_name_ref\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef\"\xeb\x02\n\x13NvmeNamespaceStatus\x12I\n\x05state\x18\x01 \x01(\x0e\x32-.opi_api.storage.v1.NvmeNamespaceStatus.StateB\x04\xe2\x41\x01\x03R\x05state\x12V\n\noper_state\x18\x02 \x01(\x0e\x32\x31.opi_api.storage.v1.NvmeNamespaceStatus.OperStateB\x04\xe2\x41\x01\x03R\toperState\"Y\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_DISABLED\x10\x01\x12\x11\n\rSTATE_ENABLED\x10\x02\x12\x12\n\x0eSTATE_DELETING\x10\x03\"V\n\tOperState\x12\x1a\n\x16OPER_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11OPER_STATE_ONLINE\x10\x01\x12\x16\n\x12OPER_STATE_OFFLINE\x10\x02\"\x9e\x01\n\x1a\x43reateNvmeSubsystemRequest\x12N\n\x0envme_subsystem\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NvmeSubsystemB\x04\xe2\x41\x01\x02R\rnvmeSubsystem\x12\x30\n\x11nvme_subsystem_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0fnvmeSubsystemId\"\x86\x01\n\x1a\x44\x65leteNvmeSubsystemRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xda\x01\n\x1aUpdateNvmeSubsystemRequest\x12N\n\x0envme_subsystem\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NvmeSubsystemB\x04\xe2\x41\x01\x02R\rnvmeSubsystem\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"c\n\x19ListNvmeSubsystemsRequest\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x90\x01\n\x1aListNvmeSubsystemsResponse\x12J\n\x0fnvme_subsystems\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NvmeSubsystemR\x0envmeSubsystems\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x17GetNvmeSubsystemRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x04name\"Z\n\x19StatsNvmeSubsystemRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x04name\"S\n\x1aStatsNvmeSubsystemResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xe7\x01\n\x1b\x43reateNvmeControllerRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x06parent\x12Q\n\x0fnvme_controller\x18\x02 \x01(\x0b\x32\".opi_api.storage.v1.NvmeControllerB\x04\xe2\x41\x01\x02R\x0envmeController\x12\x32\n\x12nvme_controller_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x10nvmeControllerId\"\x88\x01\n\x1b\x44\x65leteNvmeControllerRequest\x12>\n\x04name\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\n!opi_api.storage.v1/NvmeControllerR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xde\x01\n\x1bUpdateNvmeControllerRequest\x12Q\n\x0fnvme_controller\x18\x01 \x01(\x0b\x32\".opi_api.storage.v1.NvmeControllerB\x04\xe2\x41\x01\x02R\x0envmeController\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xa8\x01\n\x1aListNvmeControllersRequest\x12\x42\n\x06parent\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\x12!opi_api.storage.v1/NvmeControllerR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x94\x01\n\x1bListNvmeControllersResponse\x12M\n\x10nvme_controllers\x18\x01 \x03(\x0b\x32\".opi_api.storage.v1.NvmeControllerR\x0fnvmeControllers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"Z\n\x18GetNvmeControllerRequest\x12>\n\x04name\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\n!opi_api.storage.v1/NvmeControllerR\x04name\"\\\n\x1aStatsNvmeControllerRequest\x12>\n\x04name\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\n!opi_api.storage.v1/NvmeControllerR\x04name\"T\n\x1bStatsNvmeControllerResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xe1\x01\n\x1a\x43reateNvmeNamespaceRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x06parent\x12N\n\x0envme_namespace\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.NvmeNamespaceB\x04\xe2\x41\x01\x02R\rnvmeNamespace\x12\x30\n\x11nvme_namespace_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x0fnvmeNamespaceId\"\x86\x01\n\x1a\x44\x65leteNvmeNamespaceRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeNamespaceR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xda\x01\n\x1aUpdateNvmeNamespaceRequest\x12N\n\x0envme_namespace\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NvmeNamespaceB\x04\xe2\x41\x01\x02R\rnvmeNamespace\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xa6\x01\n\x19ListNvmeNamespacesRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 opi_api.storage.v1/NvmeNamespaceR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x90\x01\n\x1aListNvmeNamespacesResponse\x12J\n\x0fnvme_namespaces\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NvmeNamespaceR\x0envmeNamespaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x17GetNvmeNamespaceRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeNamespaceR\x04name\"Z\n\x19StatsNvmeNamespaceRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeNamespaceR\x04name\"S\n\x1aStatsNvmeNamespaceResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xd9\x19\n\x13\x46rontendNvmeService\x12\xb7\x01\n\x13\x43reateNvmeSubsystem\x12..opi_api.storage.v1.CreateNvmeSubsystemRequest\x1a!.opi_api.storage.v1.NvmeSubsystem\"M\xda\x41 nvme_subsystem,nvme_subsystem_id\x82\xd3\xe4\x93\x02$\"\x12/v1/nvmeSubsystems:\x0envme_subsystem\x12\x89\x01\n\x13\x44\x65leteNvmeSubsystem\x12..opi_api.storage.v1.DeleteNvmeSubsystemRequest\x1a\x16.google.protobuf.Empty\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=nvmeSubsystems/*}\x12\xc9\x01\n\x13UpdateNvmeSubsystem\x12..opi_api.storage.v1.UpdateNvmeSubsystemRequest\x1a!.opi_api.storage.v1.NvmeSubsystem\"_\xda\x41\x1anvme_subsystem,update_mask\x82\xd3\xe4\x93\x02<2*/v1/{nvme_subsystem.name=nvmeSubsystems/*}:\x0envme_subsystem\x12\x8f\x01\n\x12ListNvmeSubsystems\x12-.opi_api.storage.v1.ListNvmeSubsystemsRequest\x1a..opi_api.storage.v1.ListNvmeSubsystemsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/nvmeSubsystems\x12\x8e\x01\n\x10GetNvmeSubsystem\x12+.opi_api.storage.v1.GetNvmeSubsystemRequest\x1a!.opi_api.storage.v1.NvmeSubsystem\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{name=nvmeSubsystems/*}\x12\xa5\x01\n\x12StatsNvmeSubsystem\x12-.opi_api.storage.v1.StatsNvmeSubsystemRequest\x1a..opi_api.storage.v1.StatsNvmeSubsystemResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#\x12!/v1/{name=nvmeSubsystems/*}:stats\x12\xdf\x01\n\x14\x43reateNvmeController\x12/.opi_api.storage.v1.CreateNvmeControllerRequest\x1a\".opi_api.storage.v1.NvmeController\"r\xda\x41)parent,nvme_controller,nvme_controller_id\x82\xd3\xe4\x93\x02@\"-/v1/{parent=nvmeSubsystems/*}/nvmeControllers:\x0fnvme_controller\x12\x9d\x01\n\x14\x44\x65leteNvmeController\x12/.opi_api.storage.v1.DeleteNvmeControllerRequest\x1a\x16.google.protobuf.Empty\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/*-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}\x12\xe1\x01\n\x14UpdateNvmeController\x12/.opi_api.storage.v1.UpdateNvmeControllerRequest\x1a\".opi_api.storage.v1.NvmeController\"t\xda\x41\x1bnvme_controller,update_mask\x82\xd3\xe4\x93\x02P2=/v1/{nvme_controller.name=nvmeSubsystems/*/nvmeControllers/*}:\x0fnvme_controller\x12\xb6\x01\n\x13ListNvmeControllers\x12..opi_api.storage.v1.ListNvmeControllersRequest\x1a/.opi_api.storage.v1.ListNvmeControllersResponse\">\xda\x41\x06parent\x82\xd3\xe4\x93\x02/\x12-/v1/{parent=nvmeSubsystems/*}/nvmeControllers\x12\xa3\x01\n\x11GetNvmeController\x12,.opi_api.storage.v1.GetNvmeControllerRequest\x1a\".opi_api.storage.v1.NvmeController\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/\x12-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}\x12\xba\x01\n\x13StatsNvmeController\x12..opi_api.storage.v1.StatsNvmeControllerRequest\x1a/.opi_api.storage.v1.StatsNvmeControllerResponse\"B\xda\x41\x04name\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/{name=nvmeSubsystems/*/nvmeControllers/*}:stats\x12\xd8\x01\n\x13\x43reateNvmeNamespace\x12..opi_api.storage.v1.CreateNvmeNamespaceRequest\x1a!.opi_api.storage.v1.NvmeNamespace\"n\xda\x41\'parent,nvme_namespace,nvme_namespace_id\x82\xd3\xe4\x93\x02>\",/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces:\x0envme_namespace\x12\x9a\x01\n\x13\x44\x65leteNvmeNamespace\x12..opi_api.storage.v1.DeleteNvmeNamespaceRequest\x1a\x16.google.protobuf.Empty\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.*,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}\x12\xda\x01\n\x13UpdateNvmeNamespace\x12..opi_api.storage.v1.UpdateNvmeNamespaceRequest\x1a!.opi_api.storage.v1.NvmeNamespace\"p\xda\x41\x1anvme_namespace,update_mask\x82\xd3\xe4\x93\x02M2;/v1/{nvme_namespace.name=nvmeSubsystems/*/nvmeNamespaces/*}:\x0envme_namespace\x12\xb2\x01\n\x12ListNvmeNamespaces\x12-.opi_api.storage.v1.ListNvmeNamespacesRequest\x1a..opi_api.storage.v1.ListNvmeNamespacesResponse\"=\xda\x41\x06parent\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces\x12\x9f\x01\n\x10GetNvmeNamespace\x12+.opi_api.storage.v1.GetNvmeNamespaceRequest\x1a!.opi_api.storage.v1.NvmeNamespace\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.\x12,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}\x12\xb6\x01\n\x12StatsNvmeNamespace\x12-.opi_api.storage.v1.StatsNvmeNamespaceRequest\x1a..opi_api.storage.v1.StatsNvmeNamespaceResponse\"A\xda\x41\x04name\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}:statsB`\n\x12opi_api.storage.v1B\x11\x46rontendNvmeProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'frontend_nvme_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\021FrontendNvmeProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_NVMESUBSYSTEM'].fields_by_name['name']._options = None
  _globals['_NVMESUBSYSTEM'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMESUBSYSTEM'].fields_by_name['spec']._options = None
  _globals['_NVMESUBSYSTEM'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_NVMESUBSYSTEM'].fields_by_name['status']._options = None
  _globals['_NVMESUBSYSTEM'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_NVMESUBSYSTEM']._options = None
  _globals['_NVMESUBSYSTEM']._serialized_options = b'\352A]\n opi_api.storage.v1/NvmeSubsystem\022\032nvmeSubsystems/{subsystem}*\016nvmeSubsystems2\rnvmeSubsystem'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['nqn']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['nqn']._serialized_options = b'\342A\001\002'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['serial_number']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['serial_number']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['model_number']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['model_number']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['max_namespaces']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['max_namespaces']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['hostnqn']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['hostnqn']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['psk']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['psk']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['firmware_revision']._options = None
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['firmware_revision']._serialized_options = b'\342A\001\003'
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['fru_guid']._options = None
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['fru_guid']._serialized_options = b'\342A\001\003'
  _globals['_NVMECONTROLLER'].fields_by_name['name']._options = None
  _globals['_NVMECONTROLLER'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMECONTROLLER'].fields_by_name['spec']._options = None
  _globals['_NVMECONTROLLER'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_NVMECONTROLLER'].fields_by_name['status']._options = None
  _globals['_NVMECONTROLLER'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_NVMECONTROLLER']._options = None
  _globals['_NVMECONTROLLER']._serialized_options = b'\352A}\n!opi_api.storage.v1/NvmeController\0227nvmeSubsystems/{subsystem}/nvmeControllers/{controller}*\017nvmeControllers2\016nvmeController'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['nvme_controller_id']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['nvme_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['trtype']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['trtype']._serialized_options = b'\342A\001\002'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['pcie_id']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['pcie_id']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['fabrics_id']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['fabrics_id']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_nsq']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_nsq']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_ncq']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_ncq']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['sqes']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['sqes']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['cqes']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['cqes']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_namespaces']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_namespaces']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['min_limit']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['min_limit']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_limit']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_limit']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSTATUS'].fields_by_name['active']._options = None
  _globals['_NVMECONTROLLERSTATUS'].fields_by_name['active']._serialized_options = b'\342A\001\003'
  _globals['_NVMENAMESPACE'].fields_by_name['name']._options = None
  _globals['_NVMENAMESPACE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMENAMESPACE'].fields_by_name['spec']._options = None
  _globals['_NVMENAMESPACE'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_NVMENAMESPACE'].fields_by_name['status']._options = None
  _globals['_NVMENAMESPACE'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_NVMENAMESPACE']._options = None
  _globals['_NVMENAMESPACE']._serialized_options = b'\352Ax\n opi_api.storage.v1/NvmeNamespace\0225nvmeSubsystems/{subsystem}/nvmeNamespaces/{namespace}*\016nvmeNamespaces2\rnvmeNamespace'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['host_nsid']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['host_nsid']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['nguid']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['nguid']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['eui64']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['eui64']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['uuid']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['volume_name_ref']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['state']._options = None
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['oper_state']._options = None
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['oper_state']._serialized_options = b'\342A\001\003'
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._options = None
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem_id']._options = None
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._options = None
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMESUBSYSTEMREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMESUBSYSTEMREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_STATSNVMESUBSYSTEMREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMESUBSYSTEMREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._options = None
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller_id']._options = None
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A#\n!opi_api.storage.v1/NvmeController'
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._options = None
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A#\022!opi_api.storage.v1/NvmeController'
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A#\n!opi_api.storage.v1/NvmeController'
  _globals['_STATSNVMECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A#\n!opi_api.storage.v1/NvmeController'
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._options = None
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace_id']._options = None
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeNamespace'
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._options = None
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 opi_api.storage.v1/NvmeNamespace'
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeNamespace'
  _globals['_STATSNVMENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeNamespace'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeSubsystem']._serialized_options = b'\332A nvme_subsystem,nvme_subsystem_id\202\323\344\223\002$\"\022/v1/nvmeSubsystems:\016nvme_subsystem'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeSubsystem']._serialized_options = b'\332A\004name\202\323\344\223\002\035*\033/v1/{name=nvmeSubsystems/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeSubsystem']._serialized_options = b'\332A\032nvme_subsystem,update_mask\202\323\344\223\002<2*/v1/{nvme_subsystem.name=nvmeSubsystems/*}:\016nvme_subsystem'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeSubsystems']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeSubsystems']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/nvmeSubsystems'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeSubsystem']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1/{name=nvmeSubsystems/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeSubsystem']._serialized_options = b'\332A\004name\202\323\344\223\002#\022!/v1/{name=nvmeSubsystems/*}:stats'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeController']._serialized_options = b'\332A)parent,nvme_controller,nvme_controller_id\202\323\344\223\002@\"-/v1/{parent=nvmeSubsystems/*}/nvmeControllers:\017nvme_controller'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeController']._serialized_options = b'\332A\004name\202\323\344\223\002/*-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeController']._serialized_options = b'\332A\033nvme_controller,update_mask\202\323\344\223\002P2=/v1/{nvme_controller.name=nvmeSubsystems/*/nvmeControllers/*}:\017nvme_controller'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeControllers']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeControllers']._serialized_options = b'\332A\006parent\202\323\344\223\002/\022-/v1/{parent=nvmeSubsystems/*}/nvmeControllers'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeController']._serialized_options = b'\332A\004name\202\323\344\223\002/\022-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeController']._serialized_options = b'\332A\004name\202\323\344\223\0025\0223/v1/{name=nvmeSubsystems/*/nvmeControllers/*}:stats'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeNamespace']._serialized_options = b'\332A\'parent,nvme_namespace,nvme_namespace_id\202\323\344\223\002>\",/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces:\016nvme_namespace'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeNamespace']._serialized_options = b'\332A\004name\202\323\344\223\002.*,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeNamespace']._serialized_options = b'\332A\032nvme_namespace,update_mask\202\323\344\223\002M2;/v1/{nvme_namespace.name=nvmeSubsystems/*/nvmeNamespaces/*}:\016nvme_namespace'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeNamespaces']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeNamespaces']._serialized_options = b'\332A\006parent\202\323\344\223\002.\022,/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeNamespace']._serialized_options = b'\332A\004name\202\323\344\223\002.\022,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeNamespace']._serialized_options = b'\332A\004name\202\323\344\223\0024\0222/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}:stats'
  _globals['_NVMESUBSYSTEM']._serialized_start=239
  _globals['_NVMESUBSYSTEM']._serialized_end=514
  _globals['_NVMESUBSYSTEMSPEC']._serialized_start=517
  _globals['_NVMESUBSYSTEMSPEC']._serialized_end=745
  _globals['_NVMESUBSYSTEMSTATUS']._serialized_start=747
  _globals['_NVMESUBSYSTEMSTATUS']._serialized_end=852
  _globals['_NVMECONTROLLER']._serialized_start=855
  _globals['_NVMECONTROLLER']._serialized_end=1166
  _globals['_NVMECONTROLLERSPEC']._serialized_start=1169
  _globals['_NVMECONTROLLERSPEC']._serialized_end=1781
  _globals['_NVMECONTROLLERSTATUS']._serialized_start=1783
  _globals['_NVMECONTROLLERSTATUS']._serialized_end=1835
  _globals['_NVMENAMESPACE']._serialized_start=1838
  _globals['_NVMENAMESPACE']._serialized_end=2140
  _globals['_NVMENAMESPACESPEC']._serialized_start=2143
  _globals['_NVMENAMESPACESPEC']._serialized_end=2325
  _globals['_NVMENAMESPACESTATUS']._serialized_start=2328
  _globals['_NVMENAMESPACESTATUS']._serialized_end=2691
  _globals['_NVMENAMESPACESTATUS_STATE']._serialized_start=2514
  _globals['_NVMENAMESPACESTATUS_STATE']._serialized_end=2603
  _globals['_NVMENAMESPACESTATUS_OPERSTATE']._serialized_start=2605
  _globals['_NVMENAMESPACESTATUS_OPERSTATE']._serialized_end=2691
  _globals['_CREATENVMESUBSYSTEMREQUEST']._serialized_start=2694
  _globals['_CREATENVMESUBSYSTEMREQUEST']._serialized_end=2852
  _globals['_DELETENVMESUBSYSTEMREQUEST']._serialized_start=2855
  _globals['_DELETENVMESUBSYSTEMREQUEST']._serialized_end=2989
  _globals['_UPDATENVMESUBSYSTEMREQUEST']._serialized_start=2992
  _globals['_UPDATENVMESUBSYSTEMREQUEST']._serialized_end=3210
  _globals['_LISTNVMESUBSYSTEMSREQUEST']._serialized_start=3212
  _globals['_LISTNVMESUBSYSTEMSREQUEST']._serialized_end=3311
  _globals['_LISTNVMESUBSYSTEMSRESPONSE']._serialized_start=3314
  _globals['_LISTNVMESUBSYSTEMSRESPONSE']._serialized_end=3458
  _globals['_GETNVMESUBSYSTEMREQUEST']._serialized_start=3460
  _globals['_GETNVMESUBSYSTEMREQUEST']._serialized_end=3548
  _globals['_STATSNVMESUBSYSTEMREQUEST']._serialized_start=3550
  _globals['_STATSNVMESUBSYSTEMREQUEST']._serialized_end=3640
  _globals['_STATSNVMESUBSYSTEMRESPONSE']._serialized_start=3642
  _globals['_STATSNVMESUBSYSTEMRESPONSE']._serialized_end=3725
  _globals['_CREATENVMECONTROLLERREQUEST']._serialized_start=3728
  _globals['_CREATENVMECONTROLLERREQUEST']._serialized_end=3959
  _globals['_DELETENVMECONTROLLERREQUEST']._serialized_start=3962
  _globals['_DELETENVMECONTROLLERREQUEST']._serialized_end=4098
  _globals['_UPDATENVMECONTROLLERREQUEST']._serialized_start=4101
  _globals['_UPDATENVMECONTROLLERREQUEST']._serialized_end=4323
  _globals['_LISTNVMECONTROLLERSREQUEST']._serialized_start=4326
  _globals['_LISTNVMECONTROLLERSREQUEST']._serialized_end=4494
  _globals['_LISTNVMECONTROLLERSRESPONSE']._serialized_start=4497
  _globals['_LISTNVMECONTROLLERSRESPONSE']._serialized_end=4645
  _globals['_GETNVMECONTROLLERREQUEST']._serialized_start=4647
  _globals['_GETNVMECONTROLLERREQUEST']._serialized_end=4737
  _globals['_STATSNVMECONTROLLERREQUEST']._serialized_start=4739
  _globals['_STATSNVMECONTROLLERREQUEST']._serialized_end=4831
  _globals['_STATSNVMECONTROLLERRESPONSE']._serialized_start=4833
  _globals['_STATSNVMECONTROLLERRESPONSE']._serialized_end=4917
  _globals['_CREATENVMENAMESPACEREQUEST']._serialized_start=4920
  _globals['_CREATENVMENAMESPACEREQUEST']._serialized_end=5145
  _globals['_DELETENVMENAMESPACEREQUEST']._serialized_start=5148
  _globals['_DELETENVMENAMESPACEREQUEST']._serialized_end=5282
  _globals['_UPDATENVMENAMESPACEREQUEST']._serialized_start=5285
  _globals['_UPDATENVMENAMESPACEREQUEST']._serialized_end=5503
  _globals['_LISTNVMENAMESPACESREQUEST']._serialized_start=5506
  _globals['_LISTNVMENAMESPACESREQUEST']._serialized_end=5672
  _globals['_LISTNVMENAMESPACESRESPONSE']._serialized_start=5675
  _globals['_LISTNVMENAMESPACESRESPONSE']._serialized_end=5819
  _globals['_GETNVMENAMESPACEREQUEST']._serialized_start=5821
  _globals['_GETNVMENAMESPACEREQUEST']._serialized_end=5909
  _globals['_STATSNVMENAMESPACEREQUEST']._serialized_start=5911
  _globals['_STATSNVMENAMESPACEREQUEST']._serialized_end=6001
  _globals['_STATSNVMENAMESPACERESPONSE']._serialized_start=6003
  _globals['_STATSNVMENAMESPACERESPONSE']._serialized_end=6086
  _globals['_FRONTENDNVMESERVICE']._serialized_start=6089
  _globals['_FRONTENDNVMESERVICE']._serialized_end=9378
# @@protoc_insertion_point(module_scope)



# Add proto dir to PYTHONPATH since protoc does not create relative imports
# See this for more info https://github.com/protocolbuffers/protobuf/issues/1491
import sys
from pathlib import Path
sys.path.append(str(Path(__file__).parent))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import l3_xpu_infra_mgr_pb2 as l3__xpu__infra__mgr__pb2


class VrfServiceStub(object):
    """Management of Vrf Resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateVrf = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.VrfService/CreateVrf',
                request_serializer=l3__xpu__infra__mgr__pb2.CreateVrfRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.Vrf.FromString,
                )
        self.ListVrfs = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.VrfService/ListVrfs',
                request_serializer=l3__xpu__infra__mgr__pb2.ListVrfsRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.ListVrfsResponse.FromString,
                )
        self.GetVrf = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.VrfService/GetVrf',
                request_serializer=l3__xpu__infra__mgr__pb2.GetVrfRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.Vrf.FromString,
                )
        self.DeleteVrf = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.VrfService/DeleteVrf',
                request_serializer=l3__xpu__infra__mgr__pb2.DeleteVrfRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateVrf = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.VrfService/UpdateVrf',
                request_serializer=l3__xpu__infra__mgr__pb2.UpdateVrfRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.Vrf.FromString,
                )


class VrfServiceServicer(object):
    """Management of Vrf Resources
    """

    def CreateVrf(self, request, context):
        """Create a Vrf
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVrfs(self, request, context):
        """List Vrfs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVrf(self, request, context):
        """Retrieve a Vrf
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteVrf(self, request, context):
        """Delete a Vrf
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateVrf(self, request, context):
        """Update a Vrf
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VrfServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateVrf': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateVrf,
                    request_deserializer=l3__xpu__infra__mgr__pb2.CreateVrfRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.Vrf.SerializeToString,
            ),
            'ListVrfs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVrfs,
                    request_deserializer=l3__xpu__infra__mgr__pb2.ListVrfsRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.ListVrfsResponse.SerializeToString,
            ),
            'GetVrf': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVrf,
                    request_deserializer=l3__xpu__infra__mgr__pb2.GetVrfRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.Vrf.SerializeToString,
            ),
            'DeleteVrf': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteVrf,
                    request_deserializer=l3__xpu__infra__mgr__pb2.DeleteVrfRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateVrf': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateVrf,
                    request_deserializer=l3__xpu__infra__mgr__pb2.UpdateVrfRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.Vrf.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.network.evpn_gw.v1alpha1.VrfService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class VrfService(object):
    """Management of Vrf Resources
    """

    @staticmethod
    def CreateVrf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.VrfService/CreateVrf',
            l3__xpu__infra__mgr__pb2.CreateVrfRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.Vrf.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListVrfs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.VrfService/ListVrfs',
            l3__xpu__infra__mgr__pb2.ListVrfsRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.ListVrfsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVrf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.VrfService/GetVrf',
            l3__xpu__infra__mgr__pb2.GetVrfRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.Vrf.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteVrf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.VrfService/DeleteVrf',
            l3__xpu__infra__mgr__pb2.DeleteVrfRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateVrf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.VrfService/UpdateVrf',
            l3__xpu__infra__mgr__pb2.UpdateVrfRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.Vrf.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class SviServiceStub(object):
    """Management of switch virtual interfaces (SVIs) binding LogicalBridges to VRFs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSvi = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.SviService/CreateSvi',
                request_serializer=l3__xpu__infra__mgr__pb2.CreateSviRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.Svi.FromString,
                )
        self.ListSvis = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.SviService/ListSvis',
                request_serializer=l3__xpu__infra__mgr__pb2.ListSvisRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.ListSvisResponse.FromString,
                )
        self.GetSvi = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.SviService/GetSvi',
                request_serializer=l3__xpu__infra__mgr__pb2.GetSviRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.Svi.FromString,
                )
        self.DeleteSvi = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.SviService/DeleteSvi',
                request_serializer=l3__xpu__infra__mgr__pb2.DeleteSviRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateSvi = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.SviService/UpdateSvi',
                request_serializer=l3__xpu__infra__mgr__pb2.UpdateSviRequest.SerializeToString,
                response_deserializer=l3__xpu__infra__mgr__pb2.Svi.FromString,
                )


class SviServiceServicer(object):
    """Management of switch virtual interfaces (SVIs) binding LogicalBridges to VRFs.
    """

    def CreateSvi(self, request, context):
        """Create a Svi
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSvis(self, request, context):
        """List Svis
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSvi(self, request, context):
        """Retrieve a Svi
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSvi(self, request, context):
        """Delete a Svi
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSvi(self, request, context):
        """Update a Svi
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SviServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSvi': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSvi,
                    request_deserializer=l3__xpu__infra__mgr__pb2.CreateSviRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.Svi.SerializeToString,
            ),
            'ListSvis': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSvis,
                    request_deserializer=l3__xpu__infra__mgr__pb2.ListSvisRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.ListSvisResponse.SerializeToString,
            ),
            'GetSvi': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSvi,
                    request_deserializer=l3__xpu__infra__mgr__pb2.GetSviRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.Svi.SerializeToString,
            ),
            'DeleteSvi': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSvi,
                    request_deserializer=l3__xpu__infra__mgr__pb2.DeleteSviRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateSvi': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSvi,
                    request_deserializer=l3__xpu__infra__mgr__pb2.UpdateSviRequest.FromString,
                    response_serializer=l3__xpu__infra__mgr__pb2.Svi.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.network.evpn_gw.v1alpha1.SviService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SviService(object):
    """Management of switch virtual interfaces (SVIs) binding LogicalBridges to VRFs.
    """

    @staticmethod
    def CreateSvi(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.SviService/CreateSvi',
            l3__xpu__infra__mgr__pb2.CreateSviRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.Svi.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSvis(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.SviService/ListSvis',
            l3__xpu__infra__mgr__pb2.ListSvisRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.ListSvisResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSvi(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.SviService/GetSvi',
            l3__xpu__infra__mgr__pb2.GetSviRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.Svi.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSvi(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.SviService/DeleteSvi',
            l3__xpu__infra__mgr__pb2.DeleteSviRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSvi(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.SviService/UpdateSvi',
            l3__xpu__infra__mgr__pb2.UpdateSviRequest.SerializeToString,
            l3__xpu__infra__mgr__pb2.Svi.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import logging
import os.path

import redfish


class Managers:
    def __init__(self, host, user, password, **kwargs):
        """
        Create a new connection to DPU via Redfish.
        Due to timeout restrictions, every command will start its own session
        and tear it down once it completes.
        """
        self.logger = logging.getLogger("dpuredfish")
        self._host = host
        self._user = user
        self._password = password
        self._bmc_name = None
        self.logger.info("Connecting to %s", host)
        self._session = redfish.redfish_client(
            base_url=self._host,
            username=self._user,
            password=self._password,
            cafile=None,
            capath=None,
            max_retry=3,
            timeout=120,
            **kwargs
        )

    @property
    def bmc_name(self):
        self.logger.info("Getting System ID...")
        if self._bmc_name is not None:
            return self._bmc_name
        managers = self._session.get("/redfish/v1/Managers").obj.Members
        response = self._session.get(managers[0]["@odata.id"])
        self.logger.debug("Getting System ID ({})...".format(response.obj.Id))
        self._bmc_name = os.path.basename(managers[0]["@odata.id"])
        # TODO: should use response.obj.Id, but doesn't work on all devices (bug)
        # self._bmc_name = re.split(r"\d$", response.obj.Id)[0]
        return self._bmc_name

    def get_bmc_datetime(self):
        self.logger.info("Getting BMC time...")
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get("/redfish/v1/Managers/{}".format(self.bmc_name))
        self.logger.debug(response.text)
        self._session.logout()
        return response.dict.get("DateTime")

    def set_bmc_datetime(self, datetime_string):
        self.logger.info("Setting BMC time to {}".format(datetime_string))
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.patch(
            "/redfish/v1/Managers/{}".format(self.bmc_name),
            body={"DateTime": datetime_string},
        )
        self.logger.debug(response.text)
        self._session.logout()

    def get_bmc_networks(self):
        self.logger.info("Getting EthernetInterfaces")
        url = "/redfish/v1/Managers/{}/EthernetInterfaces?$expand=.($levels=1)".format(
            self.bmc_name
        )
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(url)
        self.logger.debug(response.text)
        self._session.logout()
        for item in response.obj.Members:
            yield item

    def get_event_log(self, log_type="Journal"):
        self.logger.info("Getting BMC logs of type {}...".format(log_type))
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.get(
            "/redfish/v1/Managers/{}/LogServices/{}/Entries".format(
                self.bmc_name, log_type
            )
        )
        self._session.logout()
        for entry in response.dict.get("Members"):
            yield entry

    def factory_reset(self):
        """
        Reset the BMC to default settings.
        """
        self.logger.info("Reset BMC to defaults")
        url = "/redfish/v1/Managers/{}/Actions/Manager.ResetToDefaults".format(
            self.bmc_name
        )
        body = {"ResetType": "ResetAll"}
        # TODO: create decorator for login/logout
        self._session.login(auth=redfish.AuthMethod.SESSION)
        response = self._session.post(url, body=body)
        self.logger.debug(response.text)
        self._session.logout()

    def reset_bmc(self, reset_type="ForceRestart"):
        """
        Restart the BMC.
        :param str reset_type: The type of reset to perform. Default is "ForceRestart".
                                Valid options are:
                               ForceOff, GracefulShutdown, GracefulRestart,
                               ForceRestart, Nmi, ForceOn, PushPowerButton, PowerCycle.
                               Note that above types valid according to redfish spec.
                               In reality, managers may implement a subset of types,
                               denoted by the ResetType@Redfish.AllowableValues field.
        """
        self.logger.info("Reset BMC")
        body = {"ResetType": "ForceRestart"}
        url = "/redfish/v1/Managers/{}/Actions/Manager.Reset".format(self.bmc_name)
        self._session.post(url, body=body)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_virtio_scsi.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x66rontend_virtio_scsi.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xb8\x01\n\x10VirtioScsiTarget\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x1f\n\x08max_luns\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x07maxLuns:i\xea\x41\x66\n#opi_api.storage.v1/VirtioScsiTarget\x12\x1avirtioScsiTargets/{volume}*\x11virtioScsiTargets2\x10virtioScsiTarget\"\xed\x02\n\x14VirtioScsiController\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12>\n\x07pcie_id\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpointB\x04\xe2\x41\x01\x02R\x06pcieId\x12?\n\tmin_limit\x18\x03 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08minLimit\x12?\n\tmax_limit\x18\x04 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08maxLimit:y\xea\x41v\n\'opi_api.storage.v1/VirtioScsiController\x12\x1evirtioScsiControllers/{volume}*\x15virtioScsiControllers2\x14virtioScsiController\"\xe4\x01\n\rVirtioScsiLun\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12,\n\x0ftarget_name_ref\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\rtargetNameRef\x12,\n\x0fvolume_name_ref\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef:]\xea\x41Z\n opi_api.storage.v1/VirtioScsiLun\x12\x17virtioScsiLuns/{volume}*\x0evirtioScsiLuns2\rvirtioScsiLun\"\xb2\x01\n\x1d\x43reateVirtioScsiTargetRequest\x12X\n\x12virtio_scsi_target\x18\x01 \x01(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetB\x04\xe2\x41\x01\x02R\x10virtioScsiTarget\x12\x37\n\x15virtio_scsi_target_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x12virtioScsiTargetId\"\x8c\x01\n\x1d\x44\x65leteVirtioScsiTargetRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTargetR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xe7\x01\n\x1dUpdateVirtioScsiTargetRequest\x12X\n\x12virtio_scsi_target\x18\x01 \x01(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetB\x04\xe2\x41\x01\x02R\x10virtioScsiTarget\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xac\x01\n\x1cListVirtioScsiTargetsRequest\x12\x44\n\x06parent\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\x12#opi_api.storage.v1/VirtioScsiTargetR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x9d\x01\n\x1dListVirtioScsiTargetsResponse\x12T\n\x13virtio_scsi_targets\x18\x01 \x03(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetR\x11virtioScsiTargets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"^\n\x1aGetVirtioScsiTargetRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTargetR\x04name\"`\n\x1cStatsVirtioScsiTargetRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTargetR\x04name\"V\n\x1dStatsVirtioScsiTargetResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xca\x01\n!CreateVirtioScsiControllerRequest\x12\x64\n\x16virtio_scsi_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerB\x04\xe2\x41\x01\x02R\x14virtioScsiController\x12?\n\x19virtio_scsi_controller_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x16virtioScsiControllerId\"\x94\x01\n!DeleteVirtioScsiControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiControllerR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xf7\x01\n!UpdateVirtioScsiControllerRequest\x12\x64\n\x16virtio_scsi_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerB\x04\xe2\x41\x01\x02R\x14virtioScsiController\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xb4\x01\n ListVirtioScsiControllersRequest\x12H\n\x06parent\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\x12\'opi_api.storage.v1/VirtioScsiControllerR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xad\x01\n!ListVirtioScsiControllersResponse\x12`\n\x17virtio_scsi_controllers\x18\x01 \x03(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerR\x15virtioScsiControllers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"f\n\x1eGetVirtioScsiControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiControllerR\x04name\"h\n StatsVirtioScsiControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiControllerR\x04name\"Z\n!StatsVirtioScsiControllerResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xa0\x01\n\x1a\x43reateVirtioScsiLunRequest\x12O\n\x0fvirtio_scsi_lun\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunB\x04\xe2\x41\x01\x02R\rvirtioScsiLun\x12\x31\n\x12virtio_scsi_lun_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0fvirtioScsiLunId\"\x86\x01\n\x1a\x44\x65leteVirtioScsiLunRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLunR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xdb\x01\n\x1aUpdateVirtioScsiLunRequest\x12O\n\x0fvirtio_scsi_lun\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunB\x04\xe2\x41\x01\x02R\rvirtioScsiLun\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xa6\x01\n\x19ListVirtioScsiLunsRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 opi_api.storage.v1/VirtioScsiLunR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x91\x01\n\x1aListVirtioScsiLunsResponse\x12K\n\x10virtio_scsi_luns\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunR\x0evirtioScsiLuns\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x17GetVirtioScsiLunRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLunR\x04name\"\x90\x01\n\x19StatsVirtioScsiLunRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLunR\x04name\x12\x34\n\x13\x63ontroller_name_ref\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x11\x63ontrollerNameRef\"S\n\x1aStatsVirtioScsiLunResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\x9c\x1a\n\x19\x46rontendVirtioScsiService\x12\xcf\x01\n\x16\x43reateVirtioScsiTarget\x12\x31.opi_api.storage.v1.CreateVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"\\\xda\x41(virtio_scsi_target,virtio_scsi_target_id\x82\xd3\xe4\x93\x02+\"\x15/v1/virtioScsiTargets:\x12virtio_scsi_target\x12\x92\x01\n\x16\x44\x65leteVirtioScsiTarget\x12\x31.opi_api.storage.v1.DeleteVirtioScsiTargetRequest\x1a\x16.google.protobuf.Empty\"-\xda\x41\x04name\x82\xd3\xe4\x93\x02 *\x1e/v1/{name=virtioScsiTargets/*}\x12\xe1\x01\n\x16UpdateVirtioScsiTarget\x12\x31.opi_api.storage.v1.UpdateVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"n\xda\x41\x1evirtio_scsi_target,update_mask\x82\xd3\xe4\x93\x02G21/v1/{virtio_scsi_target.name=virtioScsiTargets/*}:\x12virtio_scsi_target\x12\xad\x01\n\x15ListVirtioScsiTargets\x12\x30.opi_api.storage.v1.ListVirtioScsiTargetsRequest\x1a\x31.opi_api.storage.v1.ListVirtioScsiTargetsResponse\"/\xda\x41\x06parent\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{parent=virtioScsiTargets}\x12\x9a\x01\n\x13GetVirtioScsiTarget\x12..opi_api.storage.v1.GetVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"-\xda\x41\x04name\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{name=virtioScsiTargets/*}\x12\xb1\x01\n\x15StatsVirtioScsiTarget\x12\x30.opi_api.storage.v1.StatsVirtioScsiTargetRequest\x1a\x31.opi_api.storage.v1.StatsVirtioScsiTargetResponse\"3\xda\x41\x04name\x82\xd3\xe4\x93\x02&\x12$/v1/{name=virtioScsiTargets/*}:stats\x12\xeb\x01\n\x1a\x43reateVirtioScsiController\x12\x35.opi_api.storage.v1.CreateVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"l\xda\x41\x30virtio_scsi_controller,virtio_scsi_controller_id\x82\xd3\xe4\x93\x02\x33\"\x19/v1/virtioScsiControllers:\x16virtio_scsi_controller\x12\x9e\x01\n\x1a\x44\x65leteVirtioScsiController\x12\x35.opi_api.storage.v1.DeleteVirtioScsiControllerRequest\x1a\x16.google.protobuf.Empty\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$*\"/v1/{name=virtioScsiControllers/*}\x12\xfd\x01\n\x1aUpdateVirtioScsiController\x12\x35.opi_api.storage.v1.UpdateVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"~\xda\x41\"virtio_scsi_controller,update_mask\x82\xd3\xe4\x93\x02S29/v1/{virtio_scsi_controller.name=virtioScsiControllers/*}:\x16virtio_scsi_controller\x12\xbd\x01\n\x19ListVirtioScsiControllers\x12\x34.opi_api.storage.v1.ListVirtioScsiControllersRequest\x1a\x35.opi_api.storage.v1.ListVirtioScsiControllersResponse\"3\xda\x41\x06parent\x82\xd3\xe4\x93\x02$\x12\"/v1/{parent=virtioScsiControllers}\x12\xaa\x01\n\x17GetVirtioScsiController\x12\x32.opi_api.storage.v1.GetVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=virtioScsiControllers/*}\x12\xc1\x01\n\x19StatsVirtioScsiController\x12\x34.opi_api.storage.v1.StatsVirtioScsiControllerRequest\x1a\x35.opi_api.storage.v1.StatsVirtioScsiControllerResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1/{name=virtioScsiControllers/*}:stats\x12\xba\x01\n\x13\x43reateVirtioScsiLun\x12..opi_api.storage.v1.CreateVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"P\xda\x41\"virtio_scsi_lun,virtio_scsi_lun_id\x82\xd3\xe4\x93\x02%\"\x12/v1/virtioScsiLuns:\x0fvirtio_scsi_lun\x12\x89\x01\n\x13\x44\x65leteVirtioScsiLun\x12..opi_api.storage.v1.DeleteVirtioScsiLunRequest\x1a\x16.google.protobuf.Empty\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=virtioScsiLuns/*}\x12\xcc\x01\n\x13UpdateVirtioScsiLun\x12..opi_api.storage.v1.UpdateVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"b\xda\x41\x1bvirtio_scsi_lun,update_mask\x82\xd3\xe4\x93\x02>2+/v1/{virtio_scsi_lun.name=virtioScsiLuns/*}:\x0fvirtio_scsi_lun\x12\xa1\x01\n\x12ListVirtioScsiLuns\x12-.opi_api.storage.v1.ListVirtioScsiLunsRequest\x1a..opi_api.storage.v1.ListVirtioScsiLunsResponse\",\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{parent=virtioScsiLuns}\x12\x8e\x01\n\x10GetVirtioScsiLun\x12+.opi_api.storage.v1.GetVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{name=virtioScsiLuns/*}\x12\xa5\x01\n\x12StatsVirtioScsiLun\x12-.opi_api.storage.v1.StatsVirtioScsiLunRequest\x1a..opi_api.storage.v1.StatsVirtioScsiLunResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#\x12!/v1/{name=virtioScsiLuns/*}:statsBf\n\x12opi_api.storage.v1B\x17\x46rontendVirtioScsiProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'frontend_virtio_scsi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\027FrontendVirtioScsiProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_VIRTIOSCSITARGET'].fields_by_name['name']._options = None
  _globals['_VIRTIOSCSITARGET'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOSCSITARGET'].fields_by_name['max_luns']._options = None
  _globals['_VIRTIOSCSITARGET'].fields_by_name['max_luns']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOSCSITARGET']._options = None
  _globals['_VIRTIOSCSITARGET']._serialized_options = b'\352Af\n#opi_api.storage.v1/VirtioScsiTarget\022\032virtioScsiTargets/{volume}*\021virtioScsiTargets2\020virtioScsiTarget'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['name']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['pcie_id']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['pcie_id']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['min_limit']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['min_limit']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['max_limit']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['max_limit']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOSCSICONTROLLER']._options = None
  _globals['_VIRTIOSCSICONTROLLER']._serialized_options = b'\352Av\n\'opi_api.storage.v1/VirtioScsiController\022\036virtioScsiControllers/{volume}*\025virtioScsiControllers2\024virtioScsiController'
  _globals['_VIRTIOSCSILUN'].fields_by_name['name']._options = None
  _globals['_VIRTIOSCSILUN'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOSCSILUN'].fields_by_name['target_name_ref']._options = None
  _globals['_VIRTIOSCSILUN'].fields_by_name['target_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOSCSILUN'].fields_by_name['volume_name_ref']._options = None
  _globals['_VIRTIOSCSILUN'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOSCSILUN']._options = None
  _globals['_VIRTIOSCSILUN']._serialized_options = b'\352AZ\n opi_api.storage.v1/VirtioScsiLun\022\027virtioScsiLuns/{volume}*\016virtioScsiLuns2\rvirtioScsiLun'
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._options = None
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target_id']._options = None
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._options = None
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A%\022#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_STATSVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._options = None
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller_id']._options = None
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._options = None
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A)\022\'opi_api.storage.v1/VirtioScsiController'
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._options = None
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun_id']._options = None
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._options = None
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 opi_api.storage.v1/VirtioScsiLun'
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOSCSILUNREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOSCSILUNREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['controller_name_ref']._options = None
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['controller_name_ref']._serialized_options = b'\342A\001\001'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiTarget']._serialized_options = b'\332A(virtio_scsi_target,virtio_scsi_target_id\202\323\344\223\002+\"\025/v1/virtioScsiTargets:\022virtio_scsi_target'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiTarget']._serialized_options = b'\332A\004name\202\323\344\223\002 *\036/v1/{name=virtioScsiTargets/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiTarget']._serialized_options = b'\332A\036virtio_scsi_target,update_mask\202\323\344\223\002G21/v1/{virtio_scsi_target.name=virtioScsiTargets/*}:\022virtio_scsi_target'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiTargets']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiTargets']._serialized_options = b'\332A\006parent\202\323\344\223\002 \022\036/v1/{parent=virtioScsiTargets}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiTarget']._serialized_options = b'\332A\004name\202\323\344\223\002 \022\036/v1/{name=virtioScsiTargets/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiTarget']._serialized_options = b'\332A\004name\202\323\344\223\002&\022$/v1/{name=virtioScsiTargets/*}:stats'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiController']._serialized_options = b'\332A0virtio_scsi_controller,virtio_scsi_controller_id\202\323\344\223\0023\"\031/v1/virtioScsiControllers:\026virtio_scsi_controller'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiController']._serialized_options = b'\332A\004name\202\323\344\223\002$*\"/v1/{name=virtioScsiControllers/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiController']._serialized_options = b'\332A\"virtio_scsi_controller,update_mask\202\323\344\223\002S29/v1/{virtio_scsi_controller.name=virtioScsiControllers/*}:\026virtio_scsi_controller'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiControllers']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiControllers']._serialized_options = b'\332A\006parent\202\323\344\223\002$\022\"/v1/{parent=virtioScsiControllers}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiController']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1/{name=virtioScsiControllers/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiController']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1/{name=virtioScsiControllers/*}:stats'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiLun']._serialized_options = b'\332A\"virtio_scsi_lun,virtio_scsi_lun_id\202\323\344\223\002%\"\022/v1/virtioScsiLuns:\017virtio_scsi_lun'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiLun']._serialized_options = b'\332A\004name\202\323\344\223\002\035*\033/v1/{name=virtioScsiLuns/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiLun']._serialized_options = b'\332A\033virtio_scsi_lun,update_mask\202\323\344\223\002>2+/v1/{virtio_scsi_lun.name=virtioScsiLuns/*}:\017virtio_scsi_lun'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiLuns']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiLuns']._serialized_options = b'\332A\006parent\202\323\344\223\002\035\022\033/v1/{parent=virtioScsiLuns}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiLun']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1/{name=virtioScsiLuns/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiLun']._serialized_options = b'\332A\004name\202\323\344\223\002#\022!/v1/{name=virtioScsiLuns/*}:stats'
  _globals['_VIRTIOSCSITARGET']._serialized_start=246
  _globals['_VIRTIOSCSITARGET']._serialized_end=430
  _globals['_VIRTIOSCSICONTROLLER']._serialized_start=433
  _globals['_VIRTIOSCSICONTROLLER']._serialized_end=798
  _globals['_VIRTIOSCSILUN']._serialized_start=801
  _globals['_VIRTIOSCSILUN']._serialized_end=1029
  _globals['_CREATEVIRTIOSCSITARGETREQUEST']._serialized_start=1032
  _globals['_CREATEVIRTIOSCSITARGETREQUEST']._serialized_end=1210
  _globals['_DELETEVIRTIOSCSITARGETREQUEST']._serialized_start=1213
  _globals['_DELETEVIRTIOSCSITARGETREQUEST']._serialized_end=1353
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST']._serialized_start=1356
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST']._serialized_end=1587
  _globals['_LISTVIRTIOSCSITARGETSREQUEST']._serialized_start=1590
  _globals['_LISTVIRTIOSCSITARGETSREQUEST']._serialized_end=1762
  _globals['_LISTVIRTIOSCSITARGETSRESPONSE']._serialized_start=1765
  _globals['_LISTVIRTIOSCSITARGETSRESPONSE']._serialized_end=1922
  _globals['_GETVIRTIOSCSITARGETREQUEST']._serialized_start=1924
  _globals['_GETVIRTIOSCSITARGETREQUEST']._serialized_end=2018
  _globals['_STATSVIRTIOSCSITARGETREQUEST']._serialized_start=2020
  _globals['_STATSVIRTIOSCSITARGETREQUEST']._serialized_end=2116
  _globals['_STATSVIRTIOSCSITARGETRESPONSE']._serialized_start=2118
  _globals['_STATSVIRTIOSCSITARGETRESPONSE']._serialized_end=2204
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST']._serialized_start=2207
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST']._serialized_end=2409
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST']._serialized_start=2412
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST']._serialized_end=2560
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST']._serialized_start=2563
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST']._serialized_end=2810
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST']._serialized_start=2813
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST']._serialized_end=2993
  _globals['_LISTVIRTIOSCSICONTROLLERSRESPONSE']._serialized_start=2996
  _globals['_LISTVIRTIOSCSICONTROLLERSRESPONSE']._serialized_end=3169
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST']._serialized_start=3171
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST']._serialized_end=3273
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST']._serialized_start=3275
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST']._serialized_end=3379
  _globals['_STATSVIRTIOSCSICONTROLLERRESPONSE']._serialized_start=3381
  _globals['_STATSVIRTIOSCSICONTROLLERRESPONSE']._serialized_end=3471
  _globals['_CREATEVIRTIOSCSILUNREQUEST']._serialized_start=3474
  _globals['_CREATEVIRTIOSCSILUNREQUEST']._serialized_end=3634
  _globals['_DELETEVIRTIOSCSILUNREQUEST']._serialized_start=3637
  _globals['_DELETEVIRTIOSCSILUNREQUEST']._serialized_end=3771
  _globals['_UPDATEVIRTIOSCSILUNREQUEST']._serialized_start=3774
  _globals['_UPDATEVIRTIOSCSILUNREQUEST']._serialized_end=3993
  _globals['_LISTVIRTIOSCSILUNSREQUEST']._serialized_start=3996
  _globals['_LISTVIRTIOSCSILUNSREQUEST']._serialized_end=4162
  _globals['_LISTVIRTIOSCSILUNSRESPONSE']._serialized_start=4165
  _globals['_LISTVIRTIOSCSILUNSRESPONSE']._serialized_end=4310
  _globals['_GETVIRTIOSCSILUNREQUEST']._serialized_start=4312
  _globals['_GETVIRTIOSCSILUNREQUEST']._serialized_end=4400
  _globals['_STATSVIRTIOSCSILUNREQUEST']._serialized_start=4403
  _globals['_STATSVIRTIOSCSILUNREQUEST']._serialized_end=4547
  _globals['_STATSVIRTIOSCSILUNRESPONSE']._serialized_start=4549
  _globals['_STATSVIRTIOSCSILUNRESPONSE']._serialized_end=4632
  _globals['_FRONTENDVIRTIOSCSISERVICE']._serialized_start=4635
  _globals['_FRONTENDVIRTIOSCSISERVICE']._serialized_end=7991
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: middleend_encryption.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1amiddleend_encryption.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\x9a\x02\n\x0f\x45ncryptedVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12,\n\x0fvolume_name_ref\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef\x12\x16\n\x03key\x18\x03 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x03key\x12@\n\x06\x63ipher\x18\x04 \x01(\x0e\x32\".opi_api.storage.v1.EncryptionTypeB\x04\xe2\x41\x01\x02R\x06\x63ipher:e\xea\x41\x62\n\"opi_api.storage.v1/EncryptedVolume\x12\x19\x65ncryptedVolumes/{volume}*\x10\x65ncryptedVolumes2\x0f\x65ncryptedVolume\"\xaa\x01\n\x1c\x43reateEncryptedVolumeRequest\x12T\n\x10\x65ncrypted_volume\x18\x01 \x01(\x0b\x32#.opi_api.storage.v1.EncryptedVolumeB\x04\xe2\x41\x01\x02R\x0f\x65ncryptedVolume\x12\x34\n\x13\x65ncrypted_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x11\x65ncryptedVolumeId\"\x8a\x01\n\x1c\x44\x65leteEncryptedVolumeRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xe2\x01\n\x1cUpdateEncryptedVolumeRequest\x12T\n\x10\x65ncrypted_volume\x18\x01 \x01(\x0b\x32#.opi_api.storage.v1.EncryptedVolumeB\x04\xe2\x41\x01\x02R\x0f\x65ncryptedVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xaa\x01\n\x1bListEncryptedVolumesRequest\x12\x43\n\x06parent\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\x12\"opi_api.storage.v1/EncryptedVolumeR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x98\x01\n\x1cListEncryptedVolumesResponse\x12P\n\x11\x65ncrypted_volumes\x18\x01 \x03(\x0b\x32#.opi_api.storage.v1.EncryptedVolumeR\x10\x65ncryptedVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\\\n\x19GetEncryptedVolumeRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolumeR\x04name\"^\n\x1bStatsEncryptedVolumeRequest\x12?\n\x04name\x18\x01 \x01(\tB+\xe2\x41\x01\x02\xfa\x41$\n\"opi_api.storage.v1/EncryptedVolumeR\x04name\"U\n\x1cStatsEncryptedVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xbc\x08\n\x1aMiddleendEncryptionService\x12\xc5\x01\n\x15\x43reateEncryptedVolume\x12\x30.opi_api.storage.v1.CreateEncryptedVolumeRequest\x1a#.opi_api.storage.v1.EncryptedVolume\"U\xda\x41$encrypted_volume,encrypted_volume_id\x82\xd3\xe4\x93\x02(\"\x14/v1/encryptedVolumes:\x10\x65ncrypted_volume\x12\x8f\x01\n\x15\x44\x65leteEncryptedVolume\x12\x30.opi_api.storage.v1.DeleteEncryptedVolumeRequest\x1a\x16.google.protobuf.Empty\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/{name=encryptedVolumes/*}\x12\xd7\x01\n\x15UpdateEncryptedVolume\x12\x30.opi_api.storage.v1.UpdateEncryptedVolumeRequest\x1a#.opi_api.storage.v1.EncryptedVolume\"g\xda\x41\x1c\x65ncrypted_volume,update_mask\x82\xd3\xe4\x93\x02\x42\x32./v1/{encrypted_volume.name=encryptedVolumes/*}:\x10\x65ncrypted_volume\x12\xa0\x01\n\x14ListEncryptedVolumes\x12/.opi_api.storage.v1.ListEncryptedVolumesRequest\x1a\x30.opi_api.storage.v1.ListEncryptedVolumesResponse\"%\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/{parent=volumes}\x12\x96\x01\n\x12GetEncryptedVolume\x12-.opi_api.storage.v1.GetEncryptedVolumeRequest\x1a#.opi_api.storage.v1.EncryptedVolume\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=encryptedVolumes/*}\x12\xad\x01\n\x14StatsEncryptedVolume\x12/.opi_api.storage.v1.StatsEncryptedVolumeRequest\x1a\x30.opi_api.storage.v1.StatsEncryptedVolumeResponse\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%\x12#/v1/{name=encryptedVolumes/*}:statsBg\n\x12opi_api.storage.v1B\x18MiddleendEncryptionProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'middleend_encryption_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\030MiddleendEncryptionProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['name']._options = None
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['volume_name_ref']._options = None
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['key']._options = None
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['key']._serialized_options = b'\342A\001\002'
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['cipher']._options = None
  _globals['_ENCRYPTEDVOLUME'].fields_by_name['cipher']._serialized_options = b'\342A\001\002'
  _globals['_ENCRYPTEDVOLUME']._options = None
  _globals['_ENCRYPTEDVOLUME']._serialized_options = b'\352Ab\n\"opi_api.storage.v1/EncryptedVolume\022\031encryptedVolumes/{volume}*\020encryptedVolumes2\017encryptedVolume'
  _globals['_CREATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['encrypted_volume']._options = None
  _globals['_CREATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['encrypted_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['encrypted_volume_id']._options = None
  _globals['_CREATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['encrypted_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEENCRYPTEDVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEENCRYPTEDVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _globals['_DELETEENCRYPTEDVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEENCRYPTEDVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['encrypted_volume']._options = None
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['encrypted_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTENCRYPTEDVOLUMESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTENCRYPTEDVOLUMESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A$\022\"opi_api.storage.v1/EncryptedVolume'
  _globals['_LISTENCRYPTEDVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTENCRYPTEDVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTENCRYPTEDVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTENCRYPTEDVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETENCRYPTEDVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETENCRYPTEDVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _globals['_STATSENCRYPTEDVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSENCRYPTEDVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A$\n\"opi_api.storage.v1/EncryptedVolume'
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['CreateEncryptedVolume']._options = None
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['CreateEncryptedVolume']._serialized_options = b'\332A$encrypted_volume,encrypted_volume_id\202\323\344\223\002(\"\024/v1/encryptedVolumes:\020encrypted_volume'
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['DeleteEncryptedVolume']._options = None
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['DeleteEncryptedVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\037*\035/v1/{name=encryptedVolumes/*}'
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['UpdateEncryptedVolume']._options = None
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['UpdateEncryptedVolume']._serialized_options = b'\332A\034encrypted_volume,update_mask\202\323\344\223\002B2./v1/{encrypted_volume.name=encryptedVolumes/*}:\020encrypted_volume'
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['ListEncryptedVolumes']._options = None
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['ListEncryptedVolumes']._serialized_options = b'\332A\006parent\202\323\344\223\002\026\022\024/v1/{parent=volumes}'
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['GetEncryptedVolume']._options = None
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['GetEncryptedVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\037\022\035/v1/{name=encryptedVolumes/*}'
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['StatsEncryptedVolume']._options = None
  _globals['_MIDDLEENDENCRYPTIONSERVICE'].methods_by_name['StatsEncryptedVolume']._serialized_options = b'\332A\004name\202\323\344\223\002%\022#/v1/{name=encryptedVolumes/*}:stats'
  _globals['_ENCRYPTEDVOLUME']._serialized_start=246
  _globals['_ENCRYPTEDVOLUME']._serialized_end=528
  _globals['_CREATEENCRYPTEDVOLUMEREQUEST']._serialized_start=531
  _globals['_CREATEENCRYPTEDVOLUMEREQUEST']._serialized_end=701
  _globals['_DELETEENCRYPTEDVOLUMEREQUEST']._serialized_start=704
  _globals['_DELETEENCRYPTEDVOLUMEREQUEST']._serialized_end=842
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST']._serialized_start=845
  _globals['_UPDATEENCRYPTEDVOLUMEREQUEST']._serialized_end=1071
  _globals['_LISTENCRYPTEDVOLUMESREQUEST']._serialized_start=1074
  _globals['_LISTENCRYPTEDVOLUMESREQUEST']._serialized_end=1244
  _globals['_LISTENCRYPTEDVOLUMESRESPONSE']._serialized_start=1247
  _globals['_LISTENCRYPTEDVOLUMESRESPONSE']._serialized_end=1399
  _globals['_GETENCRYPTEDVOLUMEREQUEST']._serialized_start=1401
  _globals['_GETENCRYPTEDVOLUMEREQUEST']._serialized_end=1493
  _globals['_STATSENCRYPTEDVOLUMEREQUEST']._serialized_start=1495
  _globals['_STATSENCRYPTEDVOLUMEREQUEST']._serialized_end=1589
  _globals['_STATSENCRYPTEDVOLUMERESPONSE']._serialized_start=1591
  _globals['_STATSENCRYPTEDVOLUMERESPONSE']._serialized_end=1676
  _globals['_MIDDLEENDENCRYPTIONSERVICE']._serialized_start=1679
  _globals['_MIDDLEENDENCRYPTIONSERVICE']._serialized_end=2763
# @@protoc_insertion_point(module_scope)
